==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-solvers/Vectors/TSFIndexableVector.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef TSFINDEXABLEVECTOR_HPP
#define TSFINDEXABLEVECTOR_HPP

#include "TSFConfigDefs.hpp"

#include "TSFLoadableVector.hpp"
#include "TSFAccessibleVector.hpp"



namespace TSFExtended
{
  using Thyra::Index;

  /**
   * TSFExtended::IndexableVector defines an interface through which
   * elements for a vector can be accessed for both reading and writing
   * through indexing operators.  
   * 
   * Default implementations of the loadable and accessible interface
   * methods are provided. 
   * 
   * @author Kevin Long (krlong@sandia.gov)
   */
  template <class Scalar>
  class IndexableVector : public virtual LoadableVector<Scalar>,
                          public virtual AccessibleVector<Scalar>
    {
    public:
      /** virtual dtor */
      virtual ~IndexableVector() {;}

      /** read the element at the given global index */
      virtual const Scalar& operator[](Index globalIndex) const = 0 ;

      /** writable access to the element at the given global index */
      virtual Scalar& operator[](Index globalIndex) = 0 ;

      /** set a single element at the given global index */
      virtual void setElement(Index globalIndex, const Scalar& value) 
      {operator[](globalIndex) = value;}

      /** add to the existing value of 
       * a single element at the given global index */
      virtual void addToElement(Index globalIndex, const Scalar& value) 
      {operator[](globalIndex) += value;}

      /** get the element at the given global index */
      virtual const Scalar& getElement(Index globalIndex) const 
      {return operator[](globalIndex);}
    };
}


#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Vectors/TSFIndexableVector.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef TSFINDEXABLEVECTOR_HPP
#define TSFINDEXABLEVECTOR_HPP

#include "SundanceDefs.hpp"

#include "TSFLoadableVector.hpp"
#include "TSFAccessibleVector.hpp"



namespace TSFExtended
{
  

  /**
   * TSFExtended::IndexableVector defines an interface through which
   * elements for a vector can be accessed for both reading and writing
   * through indexing operators.  
   * 
   * Default implementations of the loadable and accessible interface
   * methods are provided. 
   * 
   * @author Kevin Long (krlong@sandia.gov)
   */
  template <class Scalar>
  class IndexableVector : public virtual LoadableVector<Scalar>,
                          public virtual AccessibleVector<Scalar>
    {
    public:
      /** virtual dtor */
      virtual ~IndexableVector() {;}

      /** read the element at the given global index */
      virtual const Scalar& operator[](OrdType globalIndex) const = 0 ;

      /** writable access to the element at the given global index */
      virtual Scalar& operator[](OrdType globalIndex) = 0 ;

      /** set a single element at the given global index */
      virtual void setElement(OrdType globalIndex, const Scalar& value) 
      {operator[](globalIndex) = value;}

      /** add to the existing value of 
       * a single element at the given global index */
      virtual void addToElement(OrdType globalIndex, const Scalar& value) 
      {operator[](globalIndex) += value;}

      /** get the element at the given global index */
      virtual const Scalar& getElement(OrdType globalIndex) const 
      {return operator[](globalIndex);}
    };
}


#endif
